@@ -1,4 +1,5 @@
 #include "sky.h"
+#include "skymap.h"
 #include <random>
 #include <fstream>
 
@@ -6,63 +7,22 @@ std::random_device r;
 std::default_random_engine e1(r());
 std::uniform_real_distribution<double> unitscatter(0, 1);
 
-/*
- * class Skymap:
- *    '''nasa skymap sky2000 v5r4 star catalog.'''
- * */
-starid::Skymap::Skymap(std::string pathcat) {
-    std::ifstream catfile(pathcat);
-    if (catfile.is_open()) {
-        std::string line;
-        skymaprec rec;
-        while (std::getline(catfile, line)) {
-            try {
-                try { rec.mv1 = std::stof(line.substr(232, 6)); } catch (...) {}
-                if (rec.mv1 > starid::star_brightness_limit) continue;
-                rec.iau_identifier = line.substr(0, 27);
-                try { rec.star_name = line.substr(98, 10); } catch (...) {}
-                try { rec.variablestar_name = line.substr(108, 10); } catch (...) {}
-                rec.skymap_number = std::stoi(line.substr(27, 8));
-                try { rec.hd_number = std::stoi(line.substr(35, 8)); } catch (...) {}
-                try { rec.sao_number = std::stoi(line.substr(43, 7)); } catch (...) {}
-                try { rec.dm_number = std::stoi(line.substr(50, 13)); } catch (...) {}
-                try { rec.hr_number = std::stoi(line.substr(63, 4)); } catch (...) {}
-                try { rec.wds_number = std::stoi(line.substr(67, 6)); } catch (...) {}
-                try { rec.ppm_number = std::stoi(line.substr(83, 7)); } catch (...) {}
-                try { rec.blended_position = std::stoi(line.substr(146, 1)); } catch (...) {}
-                rec.rah = std::stof(line.substr(118, 2));
-                rec.ram = std::stof(line.substr(120, 2));
-                rec.ras = std::stof(line.substr(122, 7));
-                rec.decd = std::stof(line.substr(130, 2));
-                rec.decm = std::stof(line.substr(132, 2));
-                rec.decs = std::stof(line.substr(134, 6));
-                rec.pmra_arcsec_per_year = 15.0 * std::stof(line.substr(149, 8));
-                rec.pmdec_arcsec_per_year = std::stof(line.substr(158, 7));
-                rec.decsign = 1.0;
-                rec.pmdecsign = 1.0;
-                if (line.substr(129, 1).compare("-") == 0) rec.decsign = -1.0;
-                if (line.substr(157, 1).compare("-") == 0) rec.pmdecsign = -1.0;
-                rec.fileline = line;
-                records.push_back(rec);
-            } catch (...) {
-            }
-        }
-        catfile.close();
-    }
-}
-
 /*
  * class Sky:
- *    '''model the sky, based on the skymap object.'''
+ *    '''model the sky, based on the skymap object. the key input parameter is the star brightness threshold - with visual magnitude 6.5 the sky is about nine thousand stars, and that number grows exponentially as dimmer stars are included.'''
  * */
 starid::Sky::Sky() {
 }
 
+/*
+ *    def start(self, pathin):
+ *       '''initialize the sky. first generates a skymap object and then picks out the information needed here, with some enrichment - in particular with three-dimensional vectors in the celestial reference frame.'''
+ * */
 void starid::Sky::start(std::string pathin) {
     pathcat = pathin;
     t = 0.0;
     star star;
-    starid::Skymap skymap(pathcat);
+    Skymap skymap(pathcat);
     int starndx = 0;
     for (auto rec : skymap.records) {
         star.starndx = starndx;
@@ -87,6 +47,10 @@ void starid::Sky::start(std::string pathin) {
     zndxer.sort();
 }
 
+/*
+ *    def image_generator(self, starndx):
+ *       '''creates a standard image for the target star, ready for feeding into a star identifier. the format is 28 x 28 pixels - lo-fi, the way we like it. makes thing tougher on us. and also by no coincidence matching the classic mnist character recognition data set. the story behind that is a long one, discussed elsewhere in the project.'''
+ * */
 std::map<std::string, Eigen::MatrixXd> starid::Sky::image_generator(int starndx) {
     using namespace Eigen;
     MatrixXd pixels = MatrixXd::Zero(28, 28);
@@ -136,62 +100,10 @@ std::map<std::string, Eigen::MatrixXd> starid::Sky::image_generator(int starndx)
     return result;
 }
 
-std::map<std::string, Eigen::MatrixXd> starid::Sky::angle_generator(int starndx) {
-    using namespace Eigen;
-    MatrixXd angles = MatrixXd::Zero(36, 1);
-    MatrixXd info = MatrixXd::Zero(100, 6);
-    MatrixXd targets = MatrixXd::Zero(50, 1);
-    Vector3d pointing;
-    pointing << stars[starndx].x, stars[starndx].y, stars[starndx].z;
-    std::vector<int> starndxs = stars_near_point(pointing(0), pointing(1), pointing(2));
-    MatrixXd pvecs = MatrixXd::Zero(100, 3);
-    MatrixXd ndxs = MatrixXd::Zero(100, 4);
-    int pvecsndx = 0;
-    for (auto ndx : starndxs) {
-        pvecs.row(pvecsndx) << stars[ndx].x, stars[ndx].y, stars[ndx].z;
-        ndxs.row(pvecsndx) << stars[ndx].starndx, stars[ndx].skymap_number, stars[ndx].ra_degrees, stars[ndx].dec_degrees;
-        ++pvecsndx;
-    }
-    pvecs.conservativeResize(pvecsndx, 3);
-    Matrix3d attitude = rotation_matrix(pointing);
-    pvecs = (attitude.transpose() * pvecs.transpose()).transpose();
-    double yaw = unitscatter(e1) * 2 * starid::pi;
-    int imgindx = 0;
-    for (int ndx = 0; ndx < pvecsndx; ++ndx) {
-        double x = std::cos(yaw) * pvecs(ndx, 0) - std::sin(yaw) * pvecs(ndx, 1);
-        double y = std::sin(yaw) * pvecs(ndx, 0) + std::cos(yaw) * pvecs(ndx, 1);
-        double axi = x + starid::image_radius_unit_vector_plane;
-        double axj = -y + starid::image_radius_unit_vector_plane;
-        int axindx = std::floor(axi / starid::image_pixel_unit_vector_plane);
-        int axjndx = std::floor(axj / starid::image_pixel_unit_vector_plane);
-        if (ndxs(ndx, 0) == starndx) continue;
-        if (axindx < 0 || axindx > 27) continue;
-        if (axjndx < 0 || axjndx > 27) continue;
-        info(imgindx, 0) = axjndx;
-        info(imgindx, 1) = axindx;
-        info(imgindx, 2) = ndxs(ndx, 0); // starndx
-        info(imgindx, 3) = ndxs(ndx, 1); // skymap_number
-        info(imgindx, 4) = ndxs(ndx, 2); // ra
-        info(imgindx, 5) = ndxs(ndx, 3); // dec
-        ++imgindx;
-        double pixelx = (double) axindx - 13.5;
-        double pixely = 13.5 - (double) axjndx;
-        if (std::sqrt(pixelx * pixelx + pixely * pixely) > 13.0) continue;
-        double yawrad = std::atan2(pixely, pixelx); // yaw positive counterclock from x axis
-        double yawdeg = yawrad * 180.0 / starid::pi;
-        if (yawdeg < 0.0) yawdeg = 360.0 + yawdeg;
-        if (yawdeg == 360.0) yawdeg = 359.9;
-        int yawvecndx = std::floor(yawdeg / 10.0);
-        ++angles(yawvecndx);
-    }
-    targets(0, 0) = starndx;
-    std::map<std::string, Eigen::MatrixXd> result;
-    result["angles"] = angles;
-    result["info"] = info;
-    result["stars"] = targets;
-    return result;
-}
-
+/*
+ *    def stars_near_point(self, x, y, z):
+ *       '''given a three-dimensional pointing vector in the celestial reference frame, return the identifiers for nearby stars. this is fundamental - we have to be able to call up the stars near a target on the sky. it's a rich problem we'll be discussing throughout the project documentation. here we break the three-dimensional search space down into three one-dimensional search spaces, and create a map or hash-index into each of those. in a sense - it's a three-dimensional hash map into the sky.'''
+ * */
 std::vector<int> starid::Sky::stars_near_point(double x, double y, double z) {
     double max_ang = 1.4 * starid::image_radius_radians;
     std::vector<int> xring = stars_in_ring(x, max_ang, xndxer);
@@ -208,6 +120,10 @@ std::vector<int> starid::Sky::stars_near_point(double x, double y, double z) {
     return ndxs;
 }
 
+/*
+ *    def stars_in_ring(self, p, radius, table):
+ *       '''when we break the skies three-dimensional search space down into three one-dimensional search spaces, the one-dimensional spaces represent rings on the sky. we have three rings, and the stars we're interested in are in their intersection. this intersection of three rings is in some sense a three-dimensional hash map into the sky.'''
+ * */
 std::vector<int> starid::Sky::stars_in_ring(double p, double radius, starid::range_of_floats_indexer &table) {
     double pmin, pmax;
     if (p >= cos(radius)) {
